<?php
/*
 * @package Joomla 3.2
 * @license - http://www.gnu.org/licenses/gpl-2.0.html GNU/GPL
 * @component Ejoshop
 * @copyright Copyright (C) Aleksandr Ermakov www.slyweb.ru, ermakovshop.com
 */

defined( '_JEXEC' ) or die( 'Restricted access' );



/**
 * Articles list controller class.
 *
 * @package		Joomla.Administrator
 * @subpackage	com_ejoshop
 * @since	1.6
 */
class EjoshopControllerEjoshopComments extends EjoshopController
{
	/**
	 * Constructor.
	 *
	 * @param	array	$config	An optional associative array of configuration settings.

	 * @return	ContentControllerArticles
	 * @see		JController
	 * @since	1.6
	 */
	public function __construct($config = array())
	{

		// Articles default form can come from the articles or featured view.
		// Adjust the redirect view on the value of 'view' in the request.
		if (JRequest::getCmd('view') == 'featured') {
			$this->view_list = 'featured';
		}
		parent::__construct($config);

		$this->registerTask('unfeatured',	'featured');
		$this->registerTask('commentedit',	'commentedit');
		$this->registerTask('delete',	'delete');
		$this->registerTask('edit',	'commentedit');
		$this->registerTask('apply',	'commentedit');
		$this->registerTask('add',	'photosadd');
		$this->registerTask('cancel',	'cancel');
		$this->registerTask( 'published'  , 'publishedproduct' );
		$this->registerTask( 'notpublished'  , 'publishedproduct' );
	}
    
	function remove()
    {
        JRequest::checkToken() or jexit('Invalid Token');
	
        $model = $this->getModel('EjoshopComments');
        $model->remove();
    }

	function publish()
    {
        JRequest::checkToken() or jexit('Invalid Token');
	
        $model = $this->getModel('EjoshopComments');
        $model->publish();
    }
	
    function unpublish()
    {
        JRequest::checkToken() or jexit('Invalid Token');
        $model = $this->getModel('EjoshopComments');
        $model->unpublish();
    }

	
    function trash()
    {
        JRequest::checkToken() or jexit('Invalid Token');
        $model = $this->getModel('EjoshopComments');
        $model->trash();
    }

	/**
	 * save a record (and redirect to main page)
	 * @return void
	 */
	function publishedproduct()
	{
		
		$task = $this->getTask();
		var_dump($task);
		$mainframe = JFactory::getApplication();
		if($task == 'published') {
			$f = 1;
		} else {
			$f = 0;
		} 
		
		$mainframe->setUserState('filter.published',$f);
		$published = $mainframe->getUserState('filter.published');

		$link = 'index.php?option=com_ejoshop&view=ejoshopcomments';
		
		$this->setRedirect($link, $msg);
	
	

	}
	
	/**
	 * Method to add new photos
	 *
	 * @return	void
	 * @since	1.6
	 */
	function photosadd()
	{

		JRequest::setVar( 'view', 'ejoshopcomments');
		JRequest::setVar( 'layout', 'addphotos');
		
		parent::display();	
	}
	
	
	/**
	 * Method to select a list of items with some categories.
	 *
	 * @return	void
	 * @since	1.6
	 */
	 
	function cancel()
	{
		/* delete temporary files in tmp folder */

		$link = 'index.php?option=com_ejoshop&view=ejoshopcomments';
			
		$this->setRedirect($link, $msg);
	}

	
	/**
	 * Method to select a list of items with some categories.
	 *
	 * @return	void
	 * @since	1.6
	 */
	function commentedit()
	{
		
		$task	= $this->getTask();
		$ids	= JRequest::getVar('mlid',0);


		
		$model = $this->getModel('ejoshopcomments');

			if ($model->commentedit($post)) {
				
				$msg = JText::_( 'COM_EJOSHOP_SUCCESS_EDIT' );

			} else {
				$msg = JText::_( 'COM_EJOSHOP_ERROR_EDIT' );
		
			}
				$link = 'index.php?option=com_ejoshop&view=ejoshopcomments';
				if($task == 'apply') {
					$link = 'index.php?option=com_ejoshop&view=ejoshopcomment&layout=edit&id='.$ids;
				}
				
				$this->setRedirect($link, $msg);
		
	}
	/**
	 * Method to toggle the featured setting of a list of articles.
	 *
	 * @return	void
	 * @since	1.6
	 */
	function featured()
	{
		// Check for request forgeries
		JSession::checkToken() or jexit(JText::_('JINVALID_TOKEN'));

		// Initialise variables.
		$user	= JFactory::getUser();
		$ids	= JRequest::getVar('cid', array(), '', 'array');
		$values	= array('featured' => 1, 'unfeatured' => 0);
		$task	= $this->getTask();
		$value	= JArrayHelper::getValue($values, $task, 0, 'int');

		// Access checks.
		foreach ($ids as $i => $id)
		{
			if (!$user->authorise('core.edit.state', 'com_ejoshop.article.'.(int) $id)) {
				// Prune items that you can't change.
				unset($ids[$i]);
				JError::raiseNotice(403, JText::_('JLIB_APPLICATION_ERROR_EDITSTATE_NOT_PERMITTED'));
			}
		}

		if (empty($ids)) {
			JError::raiseWarning(500, JText::_('JERROR_NO_ITEMS_SELECTED'));
		}
		else {
			// Get the model.
			$model = $this->getModel();

			// Publish the items.
			if (!$model->featured($ids, $value)) {
				JError::raiseWarning(500, $model->getError());
			}
		}

		$this->setRedirect('index.php?option=com_ejoshop&view=ejoshopcomments');
	}


	/**
	 * Proxy for getModel.
	 *
	 * @param	string	$name	The name of the model.
	 * @param	string	$prefix	The prefix for the PHP class name.
	 *
	 * @return	JModel
	 * @since	1.6
	 */
	 
	public function delete()
	{


		$post = JRequest::getVar('cid', array(), '', 'array');
		$model = $this->getModel('ejoshopcomments');
		
		if ($model->delete($post)) {
			$msg = JText::_( 'COM_EJOSHOP_SUCCESS_DELETE_ITEM' );

		} else {
			$msg = JText::_( 'COM_EJOSHOP_NOT_DELETED' );
	
		}

		$link = 'index.php?option=com_ejoshop&view=ejoshopcomments';
		$this->setRedirect($link, $msg);

					
		
	}


	/**
	 * Proxy for getModel.
	 *
	 * @param	string	$name	The name of the model.
	 * @param	string	$prefix	The prefix for the PHP class name.
	 *
	 * @return	JModel
	 * @since	1.6
	 */
	public function getModel($name = 'EjoshopPhoto', $prefix = 'EjoshopModel', $config = array('ignore_request' => true))
	{
	
		$model = parent::getModel($name, $prefix, $config);

		return $model;
	}
	

}
