<?php
/*
 * @package Joomla 3.2
 * @license - http://www.gnu.org/licenses/gpl-2.0.html GNU/GPL
 * @component Ejoshop
 * @copyright Copyright (C) Aleksandr Ermakov ermakovshop.com
 */

defined( '_JEXEC' ) or die( 'Restricted access' );



/**
 * Articles list controller class.
 *
 * @package		Joomla.Administrator
 * @subpackage	com_ejoshop
 * @since	1.6
 */
class EjoshopControllerEjoshopPhotos extends EjoshopController
{
	/**
	 * Constructor.
	 *
	 * @param	array	$config	An optional associative array of configuration settings.

	 * @return	ContentControllerArticles
	 * @see		JController
	 * @since	1.6
	 */
	public function __construct($config = array())
	{

		// Articles default form can come from the articles or featured view.
		// Adjust the redirect view on the value of 'view' in the request.
		if (JRequest::getCmd('view') == 'featured') {
			$this->view_list = 'featured';
		}
		parent::__construct($config);
		$this->registerTask('save2new',	'photoedit');
		$this->registerTask('unfeatured',	'featured');
		$this->registerTask('photoedit',	'photoedit');
		$this->registerTask('delete',	'delete');
		$this->registerTask('photoapply',	'photoedit');
		$this->registerTask('add',	'photosadd');
		$this->registerTask('cancel',	'cancel');
		$this->registerTask( 'published'  , 'publishedproduct' );
		$this->registerTask( 'notpublished'  , 'publishedproduct' );
	}
    
	function publish()
    {
        JRequest::checkToken() or jexit('Invalid Token');
	
        $model = $this->getModel('EjoshopPhotos');
        $model->publish();
    }
	
    function unpublish()
    {
        JRequest::checkToken() or jexit('Invalid Token');
        $model = $this->getModel('EjoshopPhotos');
        $model->unpublish();
    }

	
    function trash()
    {
        JRequest::checkToken() or jexit('Invalid Token');
        $model = $this->getModel('EjoshopPhotos');
        $model->trash();
    }

	/**
	 * save a record (and redirect to main page)
	 * @return void
	 */
	function publishedproduct()
	{
		
		$task = $this->getTask();
		var_dump($task);
		$mainframe = JFactory::getApplication();
		if($task == 'published') {
			$f = 1;
		} else {
			$f = 0;
		} 
		
		$mainframe->setUserState('filter.published',$f);
		$published = $mainframe->getUserState('filter.published');

		$link = 'index.php?option=com_ejoshop&view=ejoshopphotos';
		
		$this->setRedirect($link, $msg);
	
	

	}
	
	/**
	 * Method to add new photos
	 *
	 * @return	void
	 * @since	1.6
	 */
	function photosadd()
	{

		JRequest::setVar( 'view', 'ejoshopphotos');
		JRequest::setVar( 'layout', 'addphotos');
		var_dump($view);
		parent::display();	
	}
	
	
	/**
	 * Method to select a list of items with some categories.
	 *
	 * @return	void
	 * @since	1.6
	 */
	 
	function cancel()
	{
		/* delete temporary files in tmp folder */
		$dpath = $_SERVER['DOCUMENT_ROOT'].JURI::root(true).'/media/com_ejoshop/files/tmp/';
		if(is_dir($dpath)) {
			
			
			$dh = opendir($dpath);

			while($file = readdir($dh))
			{

				if(!is_dir($file))
				{
		
					@unlink($dpath.$file);
				}
			}
			closedir($dh);
		}
		$link = 'index.php?option=com_ejoshop&view=ejoshopphotos';
			
		$this->setRedirect($link, $msg);
	}

	
	/**
	 * Method to select a list of items with some categories.
	 *
	 * @return	void
	 * @since	1.6
	 */
	function photoedit()
	{

		$task	= $this->getTask();
		$ids	= JRequest::getVar('id',0);
		$imgsrc	= JRequest::getVar('imgsrc',0);
		$newproduct	= JRequest::getVar('newproduct',0);
		$app   = JFactory::getApplication();
		$data  = $this->input->post->get('jform', array(), 'array');
		$model = $this->getModel('ejoshopphoto');
		// Validate the posted data.
		// Sometimes the form needs some posted data, such as for plugins and modules.

		if($imgsrc || $newproduct) {
			$form = $model->getNewProductForm($data, false);
		} else {
			$form = $model->getForm($data, false);
		}

		$validData = $model->validate($form, $data);

		// Check for validation errors.
		if ($validData === false)
		{
		$errors = $model->getErrors();
			// Push up to three validation messages out to the user.
			for ($i = 0, $n = count($errors); $i < $n && $i < 3; $i++)
			{
				if ($errors[$i] instanceof Exception)
				{
					$app->enqueueMessage($errors[$i]->getMessage(), 'warning');
				}
				else
				{
					$app->enqueueMessage($errors[$i], 'warning');
				}
			}
			
			// Redirect back to the edit screen.
			if($imgsrc || $newproduct) {
				$this->setRedirect('index.php?option=com_ejoshop&view=ejoshopphoto&layout=edit');
			} else {
				$this->setRedirect('index.php?option=com_ejoshop&view=ejoshopphoto&layout=photoedit&id=' . $ids);
			}
			return false;
		}
		
		$model = $this->getModel('ejoshopphotos');
		// create new
		if($imgsrc || $newproduct) {
			if ($newid = $model->store()) {
			
				$msg = JText::_( 'COM_EJOSHOP_SUCCESS_STORE' );

			} else {
				$msg = JText::_( 'COM_EJOSHOP_ERROR_STORE' );
		
			}
			$link = 'index.php?option=com_ejoshop&view=ejoshopphotos';
			if($task == 'photoapply') {
				$link = 'index.php?option=com_ejoshop&view=ejoshopphoto&layout=photoedit&id='.$newid;
			}
			if($task == 'save2new') {
				$link = 'index.php?option=com_ejoshop&view=ejoshopphoto&layout=edit';
			}
			$this->setRedirect($link, $msg);
		// update existing
		} else {

			if ($model->photoedit($post)) {
				
				$msg = JText::_( 'COM_EJOSHOP_SUCCESS_EDIT' );

			} else {
				$msg = JText::_( 'COM_EJOSHOP_ERROR_EDIT' );
		
			}
				$link = 'index.php?option=com_ejoshop&view=ejoshopphotos';
				if($task == 'photoapply') {
					$link = 'index.php?option=com_ejoshop&view=ejoshopphoto&layout=photoedit&id='.$ids;
				}
				if($task == 'save2new') {
					$link = 'index.php?option=com_ejoshop&view=ejoshopphoto&layout=edit';
				}
				$this->setRedirect($link, $msg);
		}
	}
	/**
	 * Method to toggle the featured setting of a list of articles.
	 *
	 * @return	void
	 * @since	1.6
	 */
	function featured()
	{
		// Check for request forgeries
		JSession::checkToken() or jexit(JText::_('JINVALID_TOKEN'));

		// Initialise variables.
		$user	= JFactory::getUser();
		$ids	= JRequest::getVar('cid', array(), '', 'array');
		$values	= array('featured' => 1, 'unfeatured' => 0);
		$task	= $this->getTask();
		$value	= JArrayHelper::getValue($values, $task, 0, 'int');

		// Access checks.
		foreach ($ids as $i => $id)
		{
			if (!$user->authorise('core.edit.state', 'com_ejoshop.article.'.(int) $id)) {
				// Prune items that you can't change.
				unset($ids[$i]);
				JError::raiseNotice(403, JText::_('JLIB_APPLICATION_ERROR_EDITSTATE_NOT_PERMITTED'));
			}
		}

		if (empty($ids)) {
			JError::raiseWarning(500, JText::_('JERROR_NO_ITEMS_SELECTED'));
		}
		else {
			// Get the model.
			$model = $this->getModel();

			// Publish the items.
			if (!$model->featured($ids, $value)) {
				JError::raiseWarning(500, $model->getError());
			}
		}

		$this->setRedirect('index.php?option=com_ejoshop&view=ejoshopphotos');
	}


	/**
	 * Proxy for getModel.
	 *
	 * @param	string	$name	The name of the model.
	 * @param	string	$prefix	The prefix for the PHP class name.
	 *
	 * @return	JModel
	 * @since	1.6
	 */
	 
	public function delete()
	{


		$post = JRequest::getVar('cid', array(), '', 'array');
		$model = $this->getModel('ejoshopphotos');
		
		if ($model->delete($post)) {
			$msg = JText::_( 'COM_EJOSHOP_SUCCESS_DELETE_ITEM' );

		} else {
			$msg = JText::_( 'COM_EJOSHOP_NOT_DELETED' );
	
		}

		$link = 'index.php?option=com_ejoshop&view=ejoshopphotos';
		$this->setRedirect($link, $msg);

					
		
	}


	/**
	 * Proxy for getModel.
	 *
	 * @param	string	$name	The name of the model.
	 * @param	string	$prefix	The prefix for the PHP class name.
	 *
	 * @return	JModel
	 * @since	1.6
	 */
	public function getModel($name = 'EjoshopPhoto', $prefix = 'EjoshopModel', $config = array('ignore_request' => true))
	{
	
		$model = parent::getModel($name, $prefix, $config);

		return $model;
	}
	

}
