<?php
/*
 * @package Joomla 3.2
 * @license - http://www.gnu.org/licenses/gpl-2.0.html GNU/GPL
 * @component Ejoshop
 * @copyright Copyright (C) Aleksandr Ermakov ermakovshop.com
 */

defined( '_JEXEC' ) or die( 'Restricted access' );

jimport('joomla.application.component.controlleradmin');

/**
 * Articles list controller class.
 *
 * @package		Joomla.Administrator
 * @subpackage	com_ejoshop
 * @since	1.6
 */
class EjoshopControllerEjoshopTaxes extends JControllerAdmin
{
	/**
	 * Constructor.
	 *
	 * @param	array	$config	An optional associative array of configuration settings.

	 * @return	ContentControllerArticles
	 * @see		JController
	 * @since	1.6
	 */
	public function __construct($config = array())
	{

		// Articles default form can come from the articles or featured view.
		// Adjust the redirect view on the value of 'view' in the request.
		if (JRequest::getCmd('view') == 'featured') {
			$this->view_list = 'featured';
		}
		parent::__construct($config);


		
	}


	/**
	 * Method to add new photos
	 *
	 * @return	void
	 * @since	1.6
	 */
	function add()
	{

		JRequest::setVar( 'view', 'ejoshoptaxs');
		JRequest::setVar( 'layout', 'edit');

		parent::display();	
	}
	
	
	/**
	 * Method to select a list of items with some categories.
	 *
	 * @return	void
	 * @since	1.6
	 */
	 
	function cancel()
	{
		$link = 'index.php?option=com_ejoshop&view=ejoshopphotos';
			
		$this->setRedirect($link, $msg);
	}

	
	/**
	 * Method to select a list of items with some categories.
	 *
	 * @return	void
	 * @since	1.6
	 */
	function photoedit()
	{
		
		$task	= $this->getTask();
		$ids	= JRequest::getVar('id',0);

		
		$model = $this->getModel('ejoshopphotos');

		
		if ($model->photoedit($post)) {
			
			$msg = JText::_( 'COM_EJOSHOP_SUCCESS_EDIT' );

		} else {
			$msg = JText::_( 'COM_EJOSHOP_ERROR_EDIT' );
	
		}
			$link = 'index.php?option=com_ejoshop&view=ejoshopphotos';
			if($task == 'photoapply') {
				$link = 'index.php?option=com_ejoshop&view=ejoshopphoto&layout=photoedit&id='.$ids;
			}
			
			$this->setRedirect($link, $msg);
	}
	/**
	 * Method to toggle the featured setting of a list of articles.
	 *
	 * @return	void
	 * @since	1.6
	 */
	function featured()
	{
		// Check for request forgeries
		JSession::checkToken() or jexit(JText::_('JINVALID_TOKEN'));

		// Initialise variables.
		$user	= JFactory::getUser();
		$ids	= JRequest::getVar('cid', array(), '', 'array');
		$values	= array('featured' => 1, 'unfeatured' => 0);
		$task	= $this->getTask();
		$value	= JArrayHelper::getValue($values, $task, 0, 'int');

		// Access checks.
		foreach ($ids as $i => $id)
		{
			if (!$user->authorise('core.edit.state', 'com_ejoshop.article.'.(int) $id)) {
				// Prune items that you can't change.
				unset($ids[$i]);
				JError::raiseNotice(403, JText::_('JLIB_APPLICATION_ERROR_EDITSTATE_NOT_PERMITTED'));
			}
		}

		if (empty($ids)) {
			JError::raiseWarning(500, JText::_('JERROR_NO_ITEMS_SELECTED'));
		}
		else {
			// Get the model.
			$model = $this->getModel();

			// Publish the items.
			if (!$model->featured($ids, $value)) {
				JError::raiseWarning(500, $model->getError());
			}
		}

		$this->setRedirect('index.php?option=com_ejoshop&view=ejoshopphotos');
	}


	/**
	 * Proxy for getModel.
	 *
	 * @param	string	$name	The name of the model.
	 * @param	string	$prefix	The prefix for the PHP class name.
	 *
	 * @return	JModel
	 * @since	1.6
	 */
	 
	public function delete()
	{


		$post = JRequest::getVar('cid', array(), '', 'array');
		$model = $this->getModel('ejoshoptaxs');
		
		if ($model->delete($post)) {
			$msg = JText::_( 'COM_EJOSHOP_SUCCESS_DELETE_ITEM' );

		} else {
			$msg = JText::_( 'COM_EJOSHOP_NOT_DELETED' );
	
		}

		$link = 'index.php?option=com_ejoshop&view=ejoshoptaxs';
		$this->setRedirect($link, $msg);

					
		
	}


	/**
	 * Proxy for getModel.
	 *
	 * @param	string	$name	The name of the model.
	 * @param	string	$prefix	The prefix for the PHP class name.
	 *
	 * @return	JModel
	 * @since	1.6
	 */
	public function getModel($name = 'EjoshopTaxes', $prefix = 'EjoshopModel', $config = array('ignore_request' => true))
	{
	
		$model = parent::getModel($name, $prefix, $config);

		return $model;
	}
	
	
	
	public function publish()
	{
		$pks	= JRequest::getVar('cid', array(), '', 'array');
		$m = $this->getModel();
		$task	= $this->getTask();
		$state = ($task == 'publish') ? 1 : 0;
		
		if($m->publish($pks,$state)) {
			$link = 'index.php?option=com_ejoshop&view=ejoshoptaxes';
			$this->setRedirect($link);
		}
		
	}
		

}
