<?php
/*
 * @package Joomla 3.2
 * @license - http://www.gnu.org/licenses/gpl-2.0.html GNU/GPL
 * @component Ejoshop
 * @copyright Copyright (C) Aleksandr Ermakov ermakovshop.com
 */

defined( '_JEXEC' ) or die( 'Restricted access' );

jimport('joomla.application.component.modeladmin');
ejoshopimport('ejoshop.fields.fields');
ejoshopimport('ejoshop.comments.comments');


/**
 * Item Model for an Article.
 *
 * @package		Joomla.Administrator
 * @subpackage	com_ejoshop
 * @since		1.6
 */
class EjoshopModelEjoshopComment extends JModelAdmin
{
	/**
	 * @var		string	The prefix to use with controller messages.
	 * @since	1.6
	 */
	protected $text_prefix = 'com_ejoshop';
	protected $_tbl_key = 'id';
	protected $_tbl = '#__ejoshop_comments';
	public $htmlfields = '';
	
	/**
	 * Batch copy items to a new category or current.
	 *
	 * @param   integer  $value     The new category.
	 * @param   array    $pks       An array of row IDs.
	 * @param   array    $contexts  An array of item contexts.
	 *
	 * @return  mixed  An array of new IDs on success, boolean false on failure.
	 *
	 * @since	11.1
	 */
	 
	protected function batchMove($value, $pks, $contexts)
	{
	

		$categoryId = (int) $value;
		$post = JRequest::get( 'post' );
		$cids = $post['cid'];
		
		$table = $this->getTable();
		$i = 0;

		// Check that the category exists
		if ($categoryId)
		{
			$categoryTable = $this->getCatTable();
			if (!$categoryTable->load($categoryId))
			{
				if ($error = $categoryTable->getError())
				{
					// Fatal error
					$this->setError($error);
					return false;
				}
				else
				{
					$this->setError(JText::_('JLIB_APPLICATION_ERROR_BATCH_MOVE_CATEGORY_NOT_FOUND'));
					return false;
				}
			}
		}

		if (empty($categoryId))
		{
			$this->setError(JText::_('JLIB_APPLICATION_ERROR_BATCH_MOVE_CATEGORY_NOT_FOUND'));
			return false;
		}

		// Check that the user has create permission for the component
		$extension = JFactory::getApplication()->input->get('option', '');
		$user = JFactory::getUser();
		if (!$user->authorise('core.create', $extension . '.category.' . $categoryId))
		{
			$this->setError(JText::_('JLIB_APPLICATION_ERROR_BATCH_CANNOT_CREATE'));
			return false;
		}

		// Parent exists so we let's proceed
		while (!empty($pks))
		{
			// Pop the first ID off the stack
			$pk = array_shift($pks);

			$table->reset();

			// Check that the row actually exists
			if (!$table->load($pk))
			{
				if ($error = $table->getError())
				{
					// Fatal error
					$this->setError($error);
					return false;
				}
				else
				{
					// Not fatal error
					$this->setError(JText::sprintf('JLIB_APPLICATION_ERROR_BATCH_MOVE_ROW_NOT_FOUND', $pk));
					continue;
				}
			}

			// New category ID
			$table->catid = $categoryId;

			// TODO: Deal with ordering?
			//$table->ordering	= 1;

			// Get the featured state
			$featured = $table->featured;

			// Check the row.
			if (!$table->check())
			{
				$this->setError($table->getError());
				return false;
			}

			// Store the row.
			if (!$table->store())
			{
				$this->setError($table->getError());
				return false;
			}

			// Get the new item ID
			$newId = $table->get('id');

			// Add the new ID to the array
			$newIds[$i]	= $newId;
			$i++;

			// Check if the article was featured and update the #__content_frontpage table
			if ($featured == 1)
			{
				$db = $this->getDbo();
				$query = $db->getQuery(true);
				$query->insert($db->quoteName('#__content_frontpage'));
				$query->values($newId . ', 0');
				$db->setQuery($query);
				$db->query();
			}
		}

		// Clean the cache
		$this->cleanCache();

		return $newIds;
		
	}
	
	
	protected function batchCopy($value, $pks, $contexts)
	{
		$categoryId = (int) $value;
		print_r($categoryId);
		die();	
		$categoryId = (int) $value;

		$table = $this->getTable();
		$i = 0;

		// Check that the category exists
		if ($categoryId)
		{
			$categoryTable = JTable::getInstance('Category');
			if (!$categoryTable->load($categoryId))
			{
				if ($error = $categoryTable->getError())
				{
					// Fatal error
					$this->setError($error);
					return false;
				}
				else
				{
					$this->setError(JText::_('JLIB_APPLICATION_ERROR_BATCH_MOVE_CATEGORY_NOT_FOUND'));
					return false;
				}
			}
		}

		if (empty($categoryId))
		{
			$this->setError(JText::_('JLIB_APPLICATION_ERROR_BATCH_MOVE_CATEGORY_NOT_FOUND'));
			return false;
		}

		// Check that the user has create permission for the component
		$extension = JFactory::getApplication()->input->get('option', '');
		$user = JFactory::getUser();
		if (!$user->authorise('core.create', $extension . '.category.' . $categoryId))
		{
			$this->setError(JText::_('JLIB_APPLICATION_ERROR_BATCH_CANNOT_CREATE'));
			return false;
		}

		// Parent exists so we let's proceed
		while (!empty($pks))
		{
			// Pop the first ID off the stack
			$pk = array_shift($pks);

			$table->reset();

			// Check that the row actually exists
			if (!$table->load($pk))
			{
				if ($error = $table->getError())
				{
					// Fatal error
					$this->setError($error);
					return false;
				}
				else
				{
					// Not fatal error
					$this->setError(JText::sprintf('JLIB_APPLICATION_ERROR_BATCH_MOVE_ROW_NOT_FOUND', $pk));
					continue;
				}
			}

			// Alter the title & alias
			$data = $this->generateNewTitle($categoryId, $table->alias, $table->title);
			$table->title = $data['0'];
			$table->alias = $data['1'];

			// Reset the ID because we are making a copy
			$table->id = 0;

			// New category ID
			$table->catid = $categoryId;

			// TODO: Deal with ordering?
			//$table->ordering	= 1;

			// Get the featured state
			$featured = $table->featured;

			// Check the row.
			if (!$table->check())
			{
				$this->setError($table->getError());
				return false;
			}

			// Store the row.
			if (!$table->store())
			{
				$this->setError($table->getError());
				return false;
			}

			// Get the new item ID
			$newId = $table->get('id');

			// Add the new ID to the array
			$newIds[$i]	= $newId;
			$i++;

			// Check if the article was featured and update the #__content_frontpage table
			if ($featured == 1)
			{
				$db = $this->getDbo();
				$query = $db->getQuery(true);
				$query->insert($db->quoteName('#__content_frontpage'));
				$query->values($newId . ', 0');
				$db->setQuery($query);
				$db->query();
			}
		}

		// Clean the cache
		$this->cleanCache();

		return $newIds;
	}





	/**
	 * Prepare and sanitise the table data prior to saving.
	 *
	 * @param	JTable	A JTable object.
	 *
	 * @return	void
	 * @since	1.6
	 */
	protected function prepareTable($table)
	{
		// Set the publish date to now
		$db = $this->getDbo();
		if($table->state == 1 && intval($table->publish_up) == 0) {
			$table->publish_up = JFactory::getDate()->toSql();
		}

		// Increment the content version number.
		$table->version++;

		// Reorder the articles within the category so the new article is first
		if (empty($table->id)) {
			$table->reorder('catid = '.(int) $table->catid.' AND state >= 0');
		}
	}

	/**
	 * Returns a Table object, always creating it.
	 *
	 * @param	type	The table type to instantiate
	 * @param	string	A prefix for the table class name. Optional.
	 * @param	array	Configuration array for model. Optional.
	 *
	 * @return	JTable	A database object
	*/
	public function getTable($type = 'EjoshopComments', $prefix = 'Table', $config = array())
	{
		return JTable::getInstance($type, $prefix, $config);
	}


	public function getCatTable($type = 'Ejoshopcategories', $prefix = 'Table', $config = array())
	{
		return JTable::getInstance($type, $prefix, $config);
	}



	/**
	 * Method to test whether a record can be deleted.
	 *
	 * @param	object	$record	A record object.
	 *
	 * @return	boolean	True if allowed to delete the record. Defaults to the permission set in the component.
	 * @since	1.6
	 */
	protected function canDelete($record)
	{
		return true;
	}

	/**
	 * Method to test whether a record can have its state edited.
	 *
	 * @param	object	$record	A record object.
	 *
	 * @return	boolean	True if allowed to change the state of the record. Defaults to the permission set in the component.
	 * @since	1.6
	 */
	protected function canEditState($record)
	{
		return true;
	}
	


	/**
	 * Method to get the record form.
	 *
	 * @param	array	$data		Data for the form.
	 * @param	boolean	$loadData	True if the form is to load its own data (default case), false if not.
	 *
	 * @return	mixed	A JForm object on success, false on failure
	 * @since	1.6
	 */
	public function getForm($data = array(), $loadData = true)
	{

		$form = $this->loadForm('com_ejoshop.ejoshopcomment', 'ejoshopcomment', array('control' => 'jform', 'load_data' => $loadData));
		if (empty($form)) {
			return false;
		}
		$jinput = JFactory::getApplication()->input;

		// The front end calls this model and uses a_id to avoid id clashes so we need to check for that first.
		if ($jinput->get('a_id'))
		{
			$id =  $jinput->get('a_id', 0);
		}
		// The back end uses id so we use that the rest of the time and set it to 0 by default.
		else
		{
			$id =  $jinput->get('id', 0);
		}
		// Determine correct permissions to check.
		if ($this->getState('photos.id'))
		{
			$id = $this->getState('photos.id');
			// Existing record. Can only edit in selected categories.
			$form->setFieldAttribute('catid', 'action', 'core.edit');
			// Existing record. Can only edit own articles in selected categories.
			$form->setFieldAttribute('catid', 'action', 'core.edit.own');
		}
		else
		{
			// New record. Can only create in selected categories.
			$form->setFieldAttribute('catid', 'action', 'core.create');
		}

		$user = JFactory::getUser();

		// Check for existing article.
		// Modify the form based on Edit State access controls.
		if ($id != 0 && (!$user->authorise('core.edit.state', 'com_ejoshop.article.'.(int) $id))
		|| ($id == 0 && !$user->authorise('core.edit.state', 'com_ejoshop'))
		)
		{
			// Disable fields for display.
			$form->setFieldAttribute('featured', 'disabled', 'true');
			$form->setFieldAttribute('ordering', 'disabled', 'true');
			$form->setFieldAttribute('publish_up', 'disabled', 'true');
			$form->setFieldAttribute('publish_down', 'disabled', 'true');
			$form->setFieldAttribute('state', 'disabled', 'true');

			// Disable fields while saving.
			// The controller has already verified this is an article you can edit.
			$form->setFieldAttribute('featured', 'filter', 'unset');
			$form->setFieldAttribute('ordering', 'filter', 'unset');
			$form->setFieldAttribute('publish_up', 'filter', 'unset');
			$form->setFieldAttribute('publish_down', 'filter', 'unset');
			$form->setFieldAttribute('state', 'filter', 'unset');

		}

		return $form;
	}

	/**
	 * Method to get the data that should be injected in the form.
	 *
	 * @return	mixed	The data for the form.
	 * @since	1.6
	 */
	protected function loadFormData()
	{
		// Check the session for previously entered form data.
		$data = JFactory::getApplication()->getUserState('com_ejoshop.edit.article.data', array());

		if (empty($data)) {
			$data = $this->getItem();

			// Prime some default values.
			if ($this->getState('photos.id') == 0) {
				$app = JFactory::getApplication();
				$data->set('catid', JRequest::getInt('catid', $app->getUserState('com_ejoshop.photos.filter.category_id')));
			}
		}

		return $data;
	}
	
	var $_foobar;

	public function getMyForm($data = array(), $loadData = true) {
	
		ejoshopimport('ejoshop.getmyform.getmyform');
		$app	= JFactory::getApplication();
		$form = new EjoshopGetmyform();

		
		$form 	= $form->getForm();

		if (empty($form)) {
			return false;
		}
		return $form;
	}


	

	/**
	 * 
	 * @возвращает список строк в файл view.html.php
	 */
	function getPhotos($pid = 0,$limit = 0)
	{
		
		if(empty($pid)) {
			$pid = JRequest::getVar( 'id' );
		}
		
		
		$app = JFactory::getApplication(); 
		// Create a new query object.
		$db		= JFactory::getDBO();
		$query	= $db->getQuery(true);
		
		if(!$limit) $limit = JRequest::getVar('limit',$app->getCfg('list_limit'));
		$limitstart = JRequest::getVar('limitstart', 0);
		
				
		$query->select(
			$this->getState(
				'list.select',
				'photos.*'
			)
		);
		
				

		$query->from('`#__ejoshop_comments` AS photos');
		$query->select('cat.title as category_name,fm.*');
		$query->join('LEFT', '#__ejoshop_categories AS cat ON (photos.catid = cat.id)');
		$query->join('LEFT', '#__ejoshop_file_managed AS fm ON (photos.filename = fm.fid)');

		
		// Add the list ordering clause.
		$orderCol	= $this->state->get('list.ordering','photos.id');
		$orderDirn	= $this->state->get('list.direction','DESC');

		if(isset($pid)) {
			$query->where('photos.id = '.(int) $pid);
		}
		
		$query->order($db->escape($orderCol.' '.$orderDirn));
		//var_dump($query->__toString());
		$query = $db->setQuery( $query, $limitstart, $limit );
		
		
		
		$this->photos = $db->loadObjectList();
		//var_dump($this->photos);
		return $this->photos;


	}
	
	
	public function get_field($field_table_name,$field_name,$id)
	{
		$results = array();
		$db		= JFactory::getDBO();
		$query = "SELECT field . *
		FROM ".$field_table_name." field
		WHERE field.entity_id = '".$id."' AND field.deleted = 0";
		
		$db->setQuery($query);
		$field = $db->loadAssocList();

		return $field;
	}
	
	
	public function getAllFields()
	{
		$results = array();
		$db		= JFactory::getDBO();
		$query = "SELECT fc . *
		FROM #__ejoshop_field_config fc
		WHERE fc.active = 1 AND fc.storage_active = 1";
		$config = new JConfig();
		$db->setQuery($query);
		$results = $db->loadAssocList();
		
		foreach($results as $key => $field) {
			$results[$key]['field_table_name'] = $config->dbprefix . 'ejoshop_field_data_'.$field['field_name'];
		}
		return $results;
	}

	
	
	/*
	 * Custom fields for item
	 *
	 */
	
	function getFields()
	{
	
		$fieldsClass = new EjoshopFields();	
					
		// Create a new query object.
		$db		= JFactory::getDBO();
		$query	= $db->getQuery(true);
		//вставляем насройки последней карты в новую...
		$data['task'] = JRequest::getVar('task');
		$layout = JRequest::getVar('layout');
		$id = JRequest::getVar('id');


		$app = JFactory::getApplication(); 
		$limit = JRequest::getVar('limit',$app->getCfg('list_limit'));
		
		$limitstart = JRequest::getVar('limitstart', 0);
			
		$result = $this->getAllFields();

		
			foreach($result as $key => $fieldset) {
				if(!empty($fieldset['field_table_name'])) {
					$value = $data[$fieldset['field_table_name']];
					$field =  $this->get_field($fieldset['field_table_name'],$fieldset['field_name'],$id);
		
						foreach($field as $keyf => $entity) {
							$result[$key]['activevalue'] = $field[$keyf];
							$result[$key]['#value'][$entity['delta']] = $field[$keyf][$fieldset['field_name'].'_value'];
						}
					
				}
				
			
			}

			
			foreach($result as $key => $item) {
					
				if(!empty($result[$key]['type'])) {
					$f = 'get_'.$result[$key]['type'];

					$result[$key] = $fieldsClass->$f($result[$key]);
				}
			}

			
			return $fieldsClass->htmlfields;
	}

	
	/*
	 * Custom fields select with option
	 *
	 */
	
	function get_list_text($result)
	{
		
		$result['values'] = unserialize($result['data']);
		$fieldsClass = new EjoshopFields();	
		$result['allowedvalues'] = $result['values']['settings']['allowedvalues'];
		$result['allowedvaluesstring'] = '';
		if(!empty($result['allowedvalues'])) {
		
			foreach($result['allowedvalues'] as $val) {
			
					$result['allowedvaluesstring'] .= $val[0].'|'.$val[1]."\r";
				
			}			
			
			$result['allowedvalues'] = $result['allowedvaluesstring'];
		
		//var_dump($result->values['settings']['allowedvalues']);
		$element = array();
	
		$element['#value'] = $result['#value'];
			foreach($result['values']['settings']['allowedvalues'] as $key => $val) {
				
				
				$element[$val[0]] = $val[1];
				
				
			}

			if(!empty($element)) {
				EjoshopModel::addIncludePath(JPATH_COMPONENT_ADMINISTRATOR . '/models');
				//$model = EjoshopModel::getInstance('updatesmigration', 'VirtueMartModel');
				$model = EjoshopModel::getInstance('EjoshopField', 'EjoshopModel');
				$this->htmlfields .= '<li><label style="width:10%;" title="" for="field_data_'.$result['field_name'].'">'.$result['field_name'].'</label><select name="field_data_'.$result['field_name'].'">' . $fieldsClass->form_select_options($element) . '</select></li>';
				
			}
		}
		return $this->htmlfields;
	}
	
	
	/*
	 * Custom fields select with option
	 *
	 */
	
	function get_text($result)
	{
		$this->htmlfields .= '<li><label style="width:10%;" title="" for="field_data_'.$result['field_name'].'">'.$result['field_name'].'</label><textarea name="'.$result['field_name'].'"></textarea></li>';
		return $this->htmlfields;
	}
	
	
	/**
	 * Method to save the form data.
	 *
	 * @param	array	The form data.
	 *
	 * @return	boolean	True on success.
	 * @since	1.6
	 */
	public function save($data)
	{
			if (isset($data['images']) && is_array($data['images'])) {
				$registry = new JRegistry;
				$registry->loadArray($data['images']);
				$data['images'] = (string)$registry;

			}

			if (isset($data['urls']) && is_array($data['urls'])) {
				$registry = new JRegistry;
				$registry->loadArray($data['urls']);
				$data['urls'] = (string)$registry;

			}
		// Alter the title for save as copy
		if (JRequest::getVar('task') == 'save2copy') {
			list($title, $alias) = $this->generateNewTitle($data['catid'], $data['alias'], $data['title']);
			$data['title']	= $title;
			$data['alias']	= $alias;
		}

		if (parent::save($data)) {

			if (isset($data['featured'])) {
				$this->featured($this->getState($this->getName().'.id'), $data['featured']);
			}


			return true;
		}


		return false;
	}

	/**
	 * Method to toggle the featured setting of articles.
	 *
	 * @param	array	The ids of the items to toggle.
	 * @param	int		The value to toggle to.
	 *
	 * @return	boolean	True on success.
	 */
	public function featured($pks, $value = 0)
	{
		// Sanitize the ids.
		$pks = (array) $pks;
		JArrayHelper::toInteger($pks);

		if (empty($pks)) {
			$this->setError(JText::_('com_ejoshop_NO_ITEM_SELECTED'));
			return false;
		}

		$table = $this->getTable('Featured', 'ContentTable');

		try {
			$db = $this->getDbo();

			$db->setQuery(
				'UPDATE #__content' .
				' SET featured = '.(int) $value.
				' WHERE id IN ('.implode(',', $pks).')'
			);
			if (!$db->query()) {
				throw new Exception($db->getErrorMsg());
			}

			if ((int)$value == 0) {
				// Adjust the mapping table.
				// Clear the existing features settings.
				$db->setQuery(
					'DELETE FROM #__content_frontpage' .
					' WHERE content_id IN ('.implode(',', $pks).')'
				);
				if (!$db->query()) {
					throw new Exception($db->getErrorMsg());
				}
			} else {
				// first, we find out which of our new featured articles are already featured.
				$query = $db->getQuery(true);
				$query->select('f.content_id');
				$query->from('#__content_frontpage AS f');
				$query->where('content_id IN ('.implode(',', $pks).')');
				//echo $query;
				$db->setQuery($query);

				if (!is_array($old_featured = $db->loadColumn())) {
					throw new Exception($db->getErrorMsg());
				}

				// we diff the arrays to get a list of the articles that are newly featured
				$new_featured = array_diff($pks, $old_featured);

				// Featuring.
				$tuples = array();
				foreach ($new_featured as $pk) {
					$tuples[] = '('.$pk.', 0)';
				}
				if (count($tuples)) {
					$db->setQuery(
						'INSERT INTO #__content_frontpage ('.$db->quoteName('content_id').', '.$db->quoteName('ordering').')' .
						' VALUES '.implode(',', $tuples)
					);
					if (!$db->query()) {
						$this->setError($db->getErrorMsg());
						return false;
					}
				}
			}

		} catch (Exception $e) {
			$this->setError($e->getMessage());
			return false;
		}

		$table->reorder();

		$this->cleanCache();

		return true;
	}

	/**
	 * A protected method to get a set of ordering conditions.
	 *
	 * @param	object	A record object.
	 *
	 * @return	array	An array of conditions to add to add to ordering queries.
	 * @since	1.6
	 */
	protected function getReorderConditions($table)
	{
		$condition = array();
		$condition[] = 'catid = '.(int) $table->catid;
		return $condition;
	}


/**
     * Method to set the publishing state for a row or list of rows in the database
     * table.  The method respects checked out rows by other users and will attempt
     * to checkin rows that it can after adjustments are made.
     *
     * @param   mixed    $pks     An optional array of primary key values to update.
     *                            If not set the instance property value is used.
     * @param   integer  $state   The publishing state. eg. [0 = unpublished, 1 = published]
     * @param   integer  $userId  The user id of the user performing the operation.
     *
     * @return  boolean  True on success; false if $pks is empty.
     *
     * @link    http://docs.joomla.org/JTable/publish
     * @since   11.1
     */
    
	/**
	 * Method to set the publishing state for a row or list of rows in the database
	 * table.  The method respects checked out rows by other users and will attempt
	 * to checkin rows that it can after adjustments are made.
	 *
	 * @param   mixed    $pks     An optional array of primary key values to update.  If not set the instance property value is used.
	 * @param   integer  $state   The publishing state. eg. [0 = unpublished, 1 = published]
	 * @param   integer  $userId  The user id of the user performing the operation.
	 *
	 * @return  boolean  True on success.
	 *
	 * @link    http://docs.joomla.org/JTable/publish
	 * @since   11.1
	 */
	public function publish(&$pks, $state = 1)
	{
		// Initialise variables.
		$k = $this->_tbl_key;
	
		// Sanitize input.
		JArrayHelper::toInteger($pks);
		$userId = (!empty($userId)) ? $userId : 0;
		$state = (int) $state;

		// If there are no primary keys set check to see if the instance key is set.
		if (empty($pks))
		{
			if ($this->$k)
			{
				$pks = array($this->$k);
			}
			// Nothing to set publishing state on, return false.
			else
			{
				$e = new JException(JText::_('JLIB_DATABASE_ERROR_NO_ROWS_SELECTED'));
				$this->setError($e);

				return false;
			}
		}

		// Update the publishing state for rows with the given primary keys.
		$query = $this->_db->getQuery(true);
		$query->update($this->_tbl);
		$query->set('state = ' . (int) $state);

		// Determine if there is checkin support for the table.
		if (property_exists($this, 'checked_out') || property_exists($this, 'checked_out_time'))
		{
			$query->where('(checked_out = 0 OR checked_out = ' . (int) $userId . ')');
			$checkin = true;
		}
		else
		{
			$checkin = false;
		}

		// Build the WHERE clause for the primary keys.
		$query->where($k . ' = ' . implode(' OR ' . $k . ' = ', $pks));

		$this->_db->setQuery($query);

		// Check for a database error.
		if (!$this->_db->execute())
		{
			$e = new JException(JText::sprintf('JLIB_DATABASE_ERROR_PUBLISH_FAILED', get_class($this), $this->_db->getErrorMsg()));
			$this->setError($e);

			return false;
		}

		// If checkin is supported and all rows were adjusted, check them in.
		if ($checkin && (count($pks) == $this->_db->getAffectedRows()))
		{
			// Checkin the rows.
			foreach ($pks as $pk)
			{
				$this->checkin($pk);
			}
		}

		// If the JTable instance value is in the list of primary keys that were set, set the instance.
		if (in_array($this->$k, $pks))
		{
			$this->state = $state;
		}

		$this->setError('');
		return true;
	}

	
	/**
	 * Custom clean the cache of com_ejoshop and content modules
	 *
	 * @since	1.6
	 */
	protected function cleanCache($group = null, $client_id = 0)
	{
		parent::cleanCache('com_ejoshop');
		parent::cleanCache('mod_articles_archive');
		parent::cleanCache('mod_articles_categories');
		parent::cleanCache('mod_articles_category');
		parent::cleanCache('mod_articles_latest');
		parent::cleanCache('mod_articles_news');
		parent::cleanCache('mod_articles_popular');
	}
}
