<?php
/*
 * @package Joomla 3.2
 * @license - http://www.gnu.org/licenses/gpl-2.0.html GNU/GPL
 * @component Ejoshop
 * @copyright Copyright (C) Aleksandr Ermakov ermakovshop.com
 */

defined( '_JEXEC' ) or die( 'Restricted access' );

jimport('joomla.application.component.modellist');

/**
 * Methods supporting a list of contact records.
 *
 * @package		Joomla.Administrator
 * @subpackage	com_contact
 */
class EjoshopModelEjoshopContacts extends JModelList
{
	/**
	 * Constructor.
	 *
	 * @param	array	An optional associative array of configuration settings.
	 * @see		JController
	 * @since	1.6
	 */
	public function __construct($config = array())
	{
		if (empty($config['filter_fields'])) {
			$config['filter_fields'] = array(
				'id', 'photos.id',
				'name', 'photos.name',
			);
		}

		parent::__construct($config);
	}

	/**
	 * Method to auto-populate the model state.
	 *
	 * Note. Calling getState in this method will result in recursion.
	 *
	 * @return	void
	 * @since	1.6
	 */
	protected function populateState($ordering = null, $direction = null)
	{
		// Initialise variables.
		$app = JFactory::getApplication();

		// Adjust the context to support modal layouts.
		if ($layout = JRequest::getVar('layout')) {
			$this->context .= '.'.$layout;
		}

		$search = $this->getUserStateFromRequest($this->context.'.filter.search', 'filter_search');
		$this->setState('filter.search', $search);

		$published = $this->getUserStateFromRequest($this->context.'.filter.published', 'filter_published', '');
		$this->setState('filter.published', $published);

		$categoryId = $this->getUserStateFromRequest($this->context.'.filter.catid', 'filter_category_id');
		$this->setState('filter.catid', $categoryId);

	

		// List state information.
		parent::populateState('photos.name', 'asc');
	}

	/**
	 * Method to get a store id based on model configuration state.
	 *
	 * This is necessary because the model is used by the component and
	 * different modules that might need different sets of data or different
	 * ordering requirements.
	 *
	 * @param	string		$id	A prefix for the store id.
	 *
	 * @return	string		A store id.
	 * @since	1.6
	 */
	protected function getStoreId($id = '')
	{
		// Compile the store id.
		$id	.= ':'.$this->getState('filter.search');
		$id	.= ':'.$this->getState('filter.published');
		$id	.= ':'.$this->getState('filter.catid');

		return parent::getStoreId($id);
	}

	/**
	 * Build an SQL query to load the list data.
	 *
	 * @return	JDatabaseQuery
	 * @since	1.6
	 */
	protected function getListQuery()
	{
		$app = JFactory::getApplication(); 
		// Create a new query object.
		$db		= JFactory::getDBO();
		$query	= $db->getQuery(true);
		$limit = JRequest::getVar('limit',$app->getCfg('list_limit'));
		
		$limitstart = JRequest::getVar('limitstart', 0);
		
				
		$query->select(
			$this->getState(
				'list.select',
				'photos.*'
			)
		);

		$query->from('`#__ejoshop_photos` AS photos');
		$query->select('cat.title as category_name');
		$query->join('LEFT', '#__ejoshop_categories AS cat ON (photos.catid = cat.id)');
		
		// Add the list ordering clause.
		$orderCol	= $this->state->get('list.ordering');
		$orderDirn	= $this->state->get('list.direction','DESC');


		$published = $this->getState('filter.published');
		if (is_numeric($published)) {
			$query->where('photos.state = ' . (int) $published);
		}
		elseif ($published === '') {
			$query->where('(photos.state = 0 OR photos.state = 1)');
		}

		// Filter by a single or group of categories.
		$categoryId = $this->getState('filter.catid');
		if (is_numeric($categoryId)) {
			$query->where('photos.catid = '.(int) $categoryId);
		}
		elseif (is_array($categoryId)) {
			JArrayHelper::toInteger($categoryId);
			$categoryId = implode(',', $categoryId);
			$query->where('photos.catid IN ('.$categoryId.')');
		}

		// Filter by search in name.
		$search = $this->getState('filter.search');
	
	
		if (!empty($search)) {
			if (stripos($search, 'id:') === 0) {
				$query->where('photos.id = '.(int) substr($search, 3));
			}
			else {
				$search = $db->Quote('%'.$db->escape($search, true).'%');
				$query->where('(photos.name LIKE '.$search.')');
			}
		}		
		
		$query->order($db->escape($orderCol.' '.$orderDirn));


		return $query;
	}
}
