<?php
/**
 * @package     Joomla.Administrator
 * @subpackage  com_categories
 *
 * @copyright   Copyright (C) 2005 - 2013 Open Source Matters, Inc. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 */

// No direct access.
defined('_JEXEC') or die;

jimport('joomla.application.component.modeladmin');
ejoshopimport('ejoshop.fields.fields');

/**
 * Categories Component Category Model
 *
 * @package     Joomla.Administrator
 * @subpackage  com_categories
 * @since       1.6
 */
class EjoshopModelEjoshopField extends JModelAdmin
{
	/**
	 * @var    string  The prefix to use with controller messages.
	 * @since  1.6
	 */
	protected $text_prefix = 'COM_EJOSHOP';

	/**
	 * Method to test whether a record can be deleted.
	 *
	 * @param   object  $record  A record object.
	 *
	 * @return  boolean  True if allowed to delete the record. Defaults to the permission set in the component.
	 *
	 * @since	1.6
	 */
	function __construct()
	{

		parent::__construct();
		
	}
	protected function canDelete($record)
	{
		if (!empty($record->id))
		{
			if ($record->published != -2)
			{
				return;
			}
			$user = JFactory::getUser();

			return $user->authorise('core.delete', $record->extension . '.sales.' . (int) $record->id);
		}
	}

	/**
	 * Method to test whether a record can have its state changed.
	 *
	 * @param   object  $record  A record object.
	 *
	 * @return  boolean  True if allowed to change the state of the record. Defaults to the permission set in the component.
	 *
	 * @since   1.6
	 */
	protected function canEditState($record)
	{
		$user = JFactory::getUser();

		// Check for existing sales.
		if (!empty($record->id))
		{
			return $user->authorise('core.edit.state', $record->extension . '.sales.' . (int) $record->id);
		}
		// New sales, so check against the parent.
		elseif (!empty($record->parent_id))
		{
			return $user->authorise('core.edit.state', $record->extension . '.sales.' . (int) $record->parent_id);
		}
		// Default to component settings if neither sales nor parent known.
		else
		{
			return $user->authorise('core.edit.state', $record->extension);
		}
	}

	/**
	 * Auto-populate the model state.
	 *
	 * Note. Calling getState in this method will result in recursion.
	 *
	 * @return  void
	 *
	 * @since   1.6
	 */
	protected function populateState()
	{
		$app = JFactory::getApplication('administrator');

		$parentId = JRequest::getInt('parent_id');
		$this->setState('sales.parent_id', $parentId);

		// Load the User state.
		$pk = (int) JRequest::getInt('id');
		$this->setState($this->getName() . '.id', $pk);

		$extension = JRequest::getCmd('extension', 'com_content');
		$this->setState('sales.extension', $extension);
		$parts = explode('.', $extension);

		// Extract the component name
		$this->setState('sales.component', $parts[0]);

		// Extract the optional section name
		$this->setState('sales.section', (count($parts) > 1) ? $parts[1] : null);


	}




	/**
	 * Method to get the row form.
	 *
	 * @param   array    $data      Data for the form.
	 * @param   boolean  $loadData  True if the form is to load its own data (default case), false if not.
	 *
	 * @return  mixed  A JForm object on success, false on failure
	 *
	 * @since   1.6
	 */
	public function getForm($data = array(), $loadData = true)
	{
		// Initialise variables.
		$extension = $this->getState('ejoshopfields.extension');
		$jinput = JFactory::getApplication()->input;

		// A workaround to get the extension into the model for save requests.
		if (empty($extension) && isset($data['extension']))
		{
			$extension = $data['extension'];
			$parts = explode('.', $extension);

			$this->setState('ejoshopfields.extension', $extension);
			$this->setState('ejoshopfields.component', $parts[0]);
			$this->setState('ejoshopfields.section', @$parts[1]);
		}

		// Get the form.
		$form = $this->loadForm('com_ejoshop.ejoshopfields', 'ejoshopfields', array('control' => 'jform', 'load_data' => $loadData));
		
		if (empty($form))
		{
			return false;
		}

		// Modify the form based on Edit State access controls.
		if (empty($data['extension']))
		{
			$data['extension'] = $extension;
		}
		$user = JFactory::getUser();

		if (!$user->authorise('core.edit.state', $extension . '.ejoshopfields.' . $jinput->get('id')))
		{
			// Disable fields for display.
			$form->setFieldAttribute('ordering', 'disabled', 'true');
			$form->setFieldAttribute('published', 'disabled', 'true');

			// Disable fields while saving.
			// The controller has already verified this is a record you can edit.
			$form->setFieldAttribute('ordering', 'filter', 'unset');
			$form->setFieldAttribute('published', 'filter', 'unset');
		}

		return $form;
	}
	
	
	function getField()
	{
		$fieldsClass = new EjoshopFields();	
				
		$field = array();
		// Create a new query object.
		$db		= JFactory::getDBO();
		$query	= $db->getQuery(true);
		//     ...
		$data['task'] = JRequest::getVar('task');
		$id = JRequest::getVar('id');

		$app = JFactory::getApplication(); 
		$limit = JRequest::getVar('limit',$app->getCfg('list_limit'));
		
		$limitstart = JRequest::getVar('limitstart', 0);
		

		$query->from('`#__ejoshop_field_config` AS field');
		$query->select('field.*');

		$search = $this->getState('filter.search');
		$direction = $this->getState('list.direction');
		
	

		$query->where('field.id = '.$id.'');
		//$query->order('c.name');

		// Add the list ordering clause.
		$orderCol	= $this->state->get('list.ordering','id');
		$orderDirn	= $this->state->get('list.direction','ASC');
		
		$query->order($db->escape($orderCol.' '.$orderDirn));
		//var_dump($query->__toString());
		//EjoshopDeveloper::debugQuery($query,__LINE__,__FILE__);
		$db->setQuery($query);
		$field = $db->loadAssocList();
		/*
		print '<pre>';
		print_r($field);
		print '</pre>';
		*/
		
		if($field) {
			foreach($field as $key => $item) {
					
				if(!empty($field[$key]['type'])) {
					$f = 'get_'.$field[$key]['type'];
					
					$field[$key]['#html'] = $fieldsClass->$f($field[$key]);
			
					$field[$key]['values'] = unserialize($field[$key]['data']);
					
					$result['allowedvalues'] = $field[$key]['values']['settings']['allowedvalues'];
					$result['allowedvaluesstring'] = '';
					if(!empty($result['allowedvalues'])) {
						//var_dump($field);
						foreach($result['allowedvalues'] as $val) {
						
								$field[$key]['allowedvaluesstring'] .= $val[0].'|'.$val[1]."\r";
							
						}	
					}
				
				}
			}
		}

	
		return $field;
	}
	

	/**
	 * A protected method to get the where clause for the reorder
	 * This ensures that the row will be moved relative to a row with the same extension
	 *
	 * @param   JCategoryTable  $table  Current table instance
	 *
	 * @return  array  An array of conditions to add to add to ordering queries.
	 *
	 * @since   1.6
	 */
	protected function getReorderConditions($table)
	{
		return 'extension = ' . $this->_db->Quote($table->extension);
	}

	/**
	 * Method to get the data that should be injected in the form.
	 *
	 * @return  mixed  The data for the form.
	 *
	 * @since   1.6
	 */
	protected function loadFormData()
	{
		// Check the session for previously entered form data.
		$data = JFactory::getApplication()->getUserState('com_ejoshopfields.edit.' . $this->getName() . '.data', array());

		if (empty($data))
		{
			$data = $this->getItem();
		}

		return $data;
	}

	/**
	 * Method to preprocess the form.
	 *
	 * @param   JForm   $form    A JForm object.
	 * @param   mixed   $data    The data expected for the form.
	 * @param   string  $groups  The name of the plugin group to import.
	 *
	 * @return  void
	 *
	 * @see     JFormField
	 * @since   1.6
	 * @throws  Exception if there is an error in the form event.
	 */
	protected function preprocessForm(JForm $form, $data, $group = 'content')
	{
		
		jimport('joomla.filesystem.path');

		// Initialise variables.
		$lang = JFactory::getLanguage();
		$extension = $this->getState('ejoshopfields.extension');
		$component = $this->getState('ejoshopfields.component');
		$section = $this->getState('ejoshopfields.section');

		// Get the component form if it exists
		jimport('joomla.filesystem.path');
		$name = 'ejoshopfields' . ($section ? ('.' . $section) : '');

		// Looking first in the component models/forms folder
		$path = JPath::clean(JPATH_ADMINISTRATOR . "/components/$component/models/forms/$name.xml");

		// Old way: looking in the component folder
		if (!file_exists($path))
		{
			$path = JPath::clean(JPATH_ADMINISTRATOR . "/components/$component/$name.xml");
		}

		if (file_exists($path))
		{
			$lang->load($component, JPATH_BASE, null, false, false);
			$lang->load($component, JPATH_BASE, $lang->getDefault(), false, false);
			$lang->load($component, JPATH_BASE . '/components/' . $component, null, false, false);
			$lang->load($component, JPATH_BASE . '/components/' . $component, $lang->getDefault(), false, false);

			if (!$form->loadFile($path, false))
			{
				throw new Exception(JText::_('JERROR_LOADFILE_FAILED'));
			}
		}

		// Try to find the component helper.
		$eName = str_replace('com_', '', $component);
		$path = JPath::clean(JPATH_ADMINISTRATOR . "/components/$component/helpers/sales.php");

		if (file_exists($path))
		{
			require_once $path;
			$cName = ucfirst($eName) . ucfirst($section) . 'HelperCategory';

			if (class_exists($cName) && is_callable(array($cName, 'onPrepareForm')))
			{
				$lang->load($component, JPATH_BASE, null, false, false) || $lang->load($component, JPATH_BASE . '/components/' . $component, null, false, false) || $lang->load($component, JPATH_BASE, $lang->getDefault(), false, false) || $lang->load($component, JPATH_BASE . '/components/' . $component, $lang->getDefault(), false, false);
				call_user_func_array(array($cName, 'onPrepareForm'), array(&$form));

				// Check for an error.
				if ($form instanceof Exception)
				{
					$this->setError($form->getMessage());
					return false;
				}
			}
		}

		// Set the access control rules field component value.
		$form->setFieldAttribute('rules', 'component', $component);
		$form->setFieldAttribute('rules', 'section', $name);

		// Trigger the default form events.
		parent::preprocessForm($form, $data, $group);
	}

	/**
	 * Method to save the form data.
	 *
	 * @param   array  $data  The form data.
	 *
	 * @return  boolean  True on success.
	 *
	 * @since   1.6
	 */
	public function update($id)
	{
		$data = JRequest::get('post');

		JTable::addIncludePath(JPATH_ADMINISTRATOR.DS.'components'.DS.'com_ejoshop'.DS.'tables');
		//$tableProduct = JTable::getInstance('EjoshopPhotos', 'Table');
		$table		  = JTable::getInstance('ejoshopField', 'Table');
		$table->reset();
		$table->load($id);
		$data = $data['jform'];
		
	
			$f = 'settings_fields_config_'.$data['type'];
			

			if(method_exists($this,$f)) {
				$data = $this->$f($data);
			} else {

				$data = $this->default_field_settings($data);
			}
		
		


		try {
			if(!$table->bind($data)) {
			   throw new FieldException('Error bind');
			}
			
			if (!$table->store())
			{
			 throw new FieldException('Error store');
			}
		}
		catch (Exception $e) {
			echo JTEXT::_($e->getMessage());
		 
		}
		
		// Store the field and get the id back.
		//drupal_write_record('field_config', $record);

		return true;
	}
	
	
	/**
	 * Method to save the form data.
	 */
	
	public function getFieldssettings($field)
	{

		if(!empty($field[0]['data'])) {
			return unserialize($field[0]['data']);
		} else {
			return array();
		}
	}
	/**
	 * Method to save the form data to field.
	 			$field = array(
			  'field_name' => $values['field_name'],
			  'type' => $values['type'],
			  'translatable' => $values['translatable'],
			  'settings' => array('max_length' => 255,
				  'widget' => array(
					'type' => $values['widget_type'],
					'weight' => $values['weight'],
				  )
			  )
			);
	 */
	
	public function default_field_settings($post)
	{


		(!empty($post['label_field_name'])) ? $label = array('label' => $post['label_field_name']) : $label = array('label' => '');
		$settings = array('settings' => array());
		$settings['settings'] += $label;
		$fid = JRequest::getVar('id',0);
		$fieldsClass = new EjoshopFields();
		$field = $fieldsClass->get_field_info(array($fid));
	
		if(!empty($field)) {
		$data = unserialize($field[0]['data']);

			if(!$data['settings']) $data['settings'] = array();
			$data['settings'] += $settings['settings'];
		} else {
			$data['settings'] = $settings['settings'];
		}
		if(!empty($post['allowedvalues'])) {
				$post['allowedvalues'] = explode("\r", $post['allowedvalues']);

				$list_values = array();
				foreach($post['allowedvalues'] as $val) {
					$val = trim($val);
					if(!empty($val))
					$list_values[] = explode("|", $val);
					
				}
				$post['allowedvalues'] = $list_values;


				if(empty($data['settings']['allowedvalues'])) {
					$data['settings'] += array('allowedvalues' => $post['allowedvalues']);
				} else {
					$data['settings']['allowedvalues'] = $post['allowedvalues'];
				}
	
		}
		if(!empty($data['widget'])) {
			$data['settings'] += array('widget'=>$data['widget']);
		
		}

		$data['data'] = serialize(array('settings' => $data['settings']));

		return $data;

	}

	/**
	 * Method to save the form data.
	 */
	
	public function settings_fields_config_number_decimal($data)
	{
		(!empty($data['label_field_name'])) ? $label = array('label' => $data['label_field_name']) : $label = array('label' => '');
		$settings = array('settings' => array());
		$settings['settings'] += $label;

		$data['data'] = serialize($settings);
		return $data;

	}

	
	/**
	 * Method to save the form data.
	 */
	
	public function settings_fields_config_list_text($data)
	{

		$data['allowedvalues'] = explode("\r", $data['allowedvalues']);
		$list_values = array();
		foreach($data['allowedvalues'] as $val) {
			$val = trim($val);
			if(!empty($val))
	
			$list_values[] = explode("|", $val);
			
		}
			
		$data['allowedvalues'] = $list_values;
		(!empty($data['label_field_name'])) ? $label = array('label' => $data['label_field_name']) : $label = array('label' => '');
		$settings = array('settings' => array());
		$settings['settings'] += $label;
		if(!empty($data['allowedvalues'])) {
			$settings['settings'] += array('allowedvalues' => $data['allowedvalues']);

		}
		$settings['settings'] += array('widget' => 'options_select');		
		$data['data'] = serialize($settings);
		return $data;
	}
	
	/**
	 * Method to save the form data.
	 *
	 * @param   array  $data  The form data.
	 *
	 * @return  boolean  True on success.
	 *
	 * @since   1.6
	 */
	
	public function delete_field()
	{

		$fieldsClass = new EjoshopFields();		
		$ids = JRequest::getVar('cid','array');
		$f = $fieldsClass->get_field_info($ids);
		
		foreach($f as $field) {
			
			try {
				$fieldsClass->delete_field($field);
			} catch (Exception $e) {
				echo $e->getMessage();
			}
		}
		return true;
		
	}
	
	
	/**
	 * Method to save the form data.
	 *
	 * @param   array  $data  The form data.
	 *
	 * @return  boolean  True on success.
	 *
	 * @since   1.6
	 */
	public function save($pk='')
	{
		require_once( JPATH_ADMINISTRATOR.DS.'components'.DS.'com_ejoshop'.DS.'libraries'.DS.'ejoshop/fields/field/field.module');
		
		$form_values = JRequest::get('post');
		
		
		$form_values = $form_values['fields'];
		$form_values['_add_new_field']['field_name'] = $form_values['_add_new_field']['label'];
		

		// Create new field.
		$field = array();
		if (!empty($form_values['_add_new_field']['field_name'])) {

			$values = $form_values['_add_new_field'];

			$field = array(
			  'field_name' => $values['field_name'],
			  'type' => $values['type'],
			  'translatable' => $values['translatable'],
			  'settings' => array('max_length' => 255,
				  'widget' => array(
					'type' => $values['widget_type'],
					'weight' => $values['weight'],
				  )
			  )
			);
			$instance = array(
			  'field_name' => $field['field_name'],
			  'entity_type' => 'product',
			  'bundle' => $bundle,
			  'label' => $values['label'],
			  'widget' => array(
				'type' => $values['widget_type'],
				'weight' => $values['weight'],
			  ),
			);
			

			// Create the field and instance.
			try {

			  $field = field_create_field($field);
			 // field_create_instance($instance);
	   

			}
			catch (Exception $e) {

				$app = JFactory::getApplication('administrator');
				$app->enqueueMessage($e->getMessage(), 'error');
				return false;
				}
		}
		
	

		return $field;
	}



	/**
	 * Method rebuild the entire nested set tree.
	 *
	 * @return  boolean  False on failure or error, true otherwise.
	 *
	 * @since   1.6
	 */
	public function rebuild()
	{
		// Get an instance of the table object.
		$table = $this->getTable();

		if (!$table->rebuild())
		{
			$this->setError($table->getError());
			return false;
		}

		// Clear the cache
		$this->cleanCache();

		return true;
	}

	/**
	 * Method to save the reordered nested set tree.
	 * First we save the new order values in the lft values of the changed ids.
	 * Then we invoke the table rebuild to implement the new ordering.
	 *
	 * @param   array    $idArray    An array of primary key ids.
	 * @param   integer  $lft_array  The lft value
	 *
	 * @return  boolean  False on failure or error, True otherwise
	 *
	 * @since   1.6
	*/
	public function saveorder($idArray = null, $lft_array = null)
	{
		// Get an instance of the table object.
		$table = $this->getTable();

		if (!$table->saveorder($idArray, $lft_array))
		{
			$this->setError($table->getError());
			return false;
		}

		// Clear the cache
		$this->cleanCache();

		return true;
	}


}
